Module pay

Module pay 

Structs

LocalPay
Pay on the local chain with fungibles implementation if the beneficiary and the asset are both local.

Enums

VersionedLocatableAccount
Versioned locatable account type which contains both an XCM location and account_id to identify an account which exists on some chain.